---
name: MMPM Bug Report
about: Issue with MMPM
title: 'BUG: '
labels: ''
assignees: ''

---

**Describe the Bug**

Is this an issue with the CLI or GUI?

Is this something that should be put in the Wiki?

A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Operating System, Python3 Version, and Web Browser**\
(Please complete the following information)

- output from `cat /etc/os-release`

- output from `python3 --version`

- Web Browser (firefox, chrome, safari, chromium, etc)

**MMPM Log Files**

- Attach the file produced `Download MMPM log files` within the Control Center of the GUI or from the  `mmpm log --zip`

- your MagicMirror `config.js`
